flash_message library
A library for displaying flash messages in the application.
Classes
- FlashMessage
- Model class for flash messages
- FlashMessageOverlay
- Widget that provides flash message functionality to its descendants
- FlashMessageService
- Service to manage flash messages
- FlashMessageWidget
- A widget that displays a flash message with an icon, message, and optional description.
Enums
- FlashMessagePosition
- Enum representing the position of the flash message on the screen.
- FlashMessageType
- Defines the type of flash message to be displayed