FlashMessageService class
Service to manage flash messages
Constructors
- FlashMessageService()
-
Factory constructor to return the same static instance
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
messages
→ Stream<
FlashMessage> -
Stream of flash messages
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clearMessages(
) → void -
dispose(
) → void - Disposes of the service
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
showMessage(
{required String message, String? description, FlashMessageType type = FlashMessageType.info, Duration duration = const Duration(seconds: 3), Color? backgroundColor, Color? textColor, IconData? icon, VoidCallback? onTap}) → void - Shows a new flash message
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited